module OrientDb
  class CollectionRepository < Base
    include OrientDb::Methods::EdgeMethods

    def build_object(args={})
      Collection.new(args.merge(id: args['@rid'],
                                name: args['name']))
    end

    def create_bookmarks_collection(user)
      bookmarks = Bookmarks.new(owner: user)

      if !has_bookmarks?(user)
        create bookmarks
      end
    end

    def destroy_bookmarks_collection(user)
      bookmarks = Bookmarks.new(owner: user)

      if has_bookmarks?(user)
        destroy bookmarks
      end
    end

    def create(object)
      super(object)
      create_edge "BelongsTo", object.id, object.owner.rid
    end

    def destroy(object)
      super(object)
      destroy_edge "BelongsTo", object.id, object.owner.rid
    end

    def all(user)
      build_objects(connection.query(sprintf("select expand(in('BelongsTo')) from %s", user.rid)))
    end

    def bookmarks(user)
      result = connection.query(sprintf("select expand(in('BelongsTo')) from %s where name = '%s'", user.rid, 'Bookmarks'))
      build_object(result.first)
    end

    def has_bookmarks?(user)
      edge_exists? 'BelongsTo', user.bookmarks.id, user.rid
    end

    def build_hash(object)
      hash = super(object)
      hash.delete("owner")
      hash
    end

    private

    def odb_class
      "Collection"
    end

  end
end
