Rails.application.routes.draw do
  require 'sidekiq/web'

  devise_for :users

  namespace :auth do
    mount_devise_token_auth_for 'User', skip: [:omniauth_callbacks]
  end

  namespace :management do
    root 'welcome#index'

    resources :statistics do
      collection do
        get :users
        get :collections
        get :accesses
        get :downloads
      end
    end

    resources :users
    resources :highlights
    resources :carousels

    mount Sidekiq::Web, at: '/sidekiq'
  end

  root 'welcome#index'

  resources :learning_objects do
    member do
      post :like
    end
  end

  resources :institutions
  resources :collections
  resources :subjects, only: [:index, :show]
  resources :complaints, only: [:create, :destroy]

  resources :users, only: [:show] do
    collection do
      get :me
    end
  end

  get '/search' => 'search#index', as: 'search'
  get '/search/fetch' => 'search#fetch', as: 'search_fetch'
  get '/subject/:id' => 'welcome#subject', as:'subject_index'
  get '/collection' => 'welcome#collection'
  get '/account' => 'welcome#account'
  get '/add_file' => 'welcome#add_file'
  get '/signup' => 'welcome#signup'
end
